@@ -510,7 +510,7 @@ if (na.miss.X & !na.miss.Y) {
 
 
 if (kk==1) {
-cat("____Il y a des NA dans X et pas dans Y____\n")
+cat("____There are some NAs in X but not in Y____\n")
 }
 
 ##############################################
@@ -645,7 +645,7 @@ cat("Not available, please use PLS_v2_kfoldcv\n")
 
 else {
 if (kk==1) {
-cat("____Il y a des NA dans X et aussi dans Y____\n")
+cat("____There are some NAs both in X and Y____\n")
 }
 }
 }
@@ -742,7 +742,7 @@ for (ii in 1:nrow(PredictYwotNA)) {
 colnames(res$ttPredictY) <- paste("tt",1:nt,sep="")
 }
 else {
-cat("____Il y a des NA dans X et aussi dans Y____\n")
+cat("____There are some NAs both in X and Y____\n")
 }
 }
 
