@@ -8,9 +8,22 @@ PLS_glm_wvc <- function(dataY,dataX,nt=2,dataPredictY=dataX,modele="pls",family=
 
 cat("____************************************************____\n")
 if (!is.data.frame(dataX)) {dataX <- data.frame(dataX)}
-if (!(modele %in% c("pls","pls-glm-logistic","pls-glm-gaussian","pls-glm-polr"))) {break}
-if (modele=="pls-glm-logistic") {family<-binomial()}
-if (modele=="pls-glm-gaussian") {family<-gaussian()}
+if (is.null(modele) & !is.null(family)) {modele<-"pls-glm-family"}
+if (!(modele %in% c("pls","pls-glm-logistic","pls-glm-family","pls-glm-Gamma","pls-glm-gaussian","pls-glm-inverse.gaussian","pls-glm-poisson","pls-glm-polr"))) {break}
+if (!(modele %in% "pls-glm-family") & !is.null(family)) {break}
+if (modele=="pls") {family<-NULL}
+if (modele=="pls-glm-Gamma") {family<-Gamma(link = "inverse")}
+if (modele=="pls-glm-gaussian") {family<-gaussian(link = "identity")}
+if (modele=="pls-glm-inverse.gaussian") {family<-inverse.gaussian(link = "1/mu^2")}
+if (modele=="pls-glm-logistic") {family<-binomial(link = "logit")}
+if (modele=="pls-glm-poisson") {family<-poisson(link = "log")}
+if (modele=="pls-glm-polr") {family<-NULL}
+if (!is.null(family)) {
+    if (is.character(family)) {family <- get(family, mode = "function", envir = parent.frame())}
+    if (is.function(family)) {family <- family()}
+    if (is.language(family)) {family <- eval(family)}
+}
+print(family)
 scaleY <- NULL
 if (is.null(scaleY)) {
 if (!(modele %in% c("pls"))) {scaleY <- FALSE} else {scaleY <- TRUE}
@@ -30,6 +43,8 @@ else {
     attr(ExpliX,"scaled:scale") <- rep(1,ncol(dataX))
     PredictY <- (dataPredictY)
 }
+if(is.null(colnames(ExpliX))){colnames(ExpliX)<-paste("X",1:ncol(ExpliX),sep=".")}
+if(is.null(rownames(ExpliX))){rownames(ExpliX)<-1:nrow(ExpliX)}
 
 if (any(is.na(dataX))) {na.miss.X <- TRUE} else na.miss.X <- FALSE
 if (any(is.na(dataY))) {na.miss.Y <- TRUE} else na.miss.Y <- FALSE
@@ -58,7 +73,7 @@ dataYwotNA[!YNA] <- 0
 PredictYwotNA <- as.matrix(PredictY)
 PredictYwotNA [is.na(PredictY)] <- 0
 
-if (modele == "pls-glm-polr") {
+if (modele %in% "pls-glm-polr") {
 dataY <- as.factor(dataY)
 YwotNA <- as.factor(YwotNA)}
 
@@ -68,7 +83,7 @@ res$temppred <- NULL
 ##############################################
 ######                PLS               ######
 ##############################################
-if (modele == "pls") {
+if (modele %in% "pls") {
 if (scaleY) {res$YChapeau=rep(attr(RepY,"scaled:center"),nrow(ExpliX))
 res$residYChapeau=rep(0,nrow(ExpliX))}
 else
@@ -123,14 +138,14 @@ tempww <- rep(0,res$nc)
 ##############################################
 ######                PLS               ######
 ##############################################
-if (modele == "pls") {
+if (modele %in% "pls") {
 tempww <- t(XXwotNA)%*%YwotNA/(t(XXNA)%*%YwotNA^2)
 }
 
 ##############################################
 ######              PLS-GLM             ######
 ##############################################
-if (modele %in% c("pls-glm-gaussian","pls-glm-logistic")) {
+if (modele %in% c("pls-glm-logistic","pls-glm-family","pls-glm-Gamma","pls-glm-gaussian","pls-glm-inverse.gaussian","pls-glm-poisson")) {
 XXwotNA[!XXNA] <- NA
 for (jj in 1:(res$nc)) {
     tempww[jj] <- coef(glm(YwotNA~cbind(res$tt,XXwotNA[,jj]),family=family))[kk+1]
@@ -250,7 +265,7 @@ rownames(res$Std.Coeffs) <- c("Intercept",colnames(ExpliX))
 ##############################################
 ######              PLS-GLM             ######
 ##############################################
-if (modele %in% c("pls-glm-logistic","pls-glm-gaussian")) {
+if (modele %in% c("pls-glm-logistic","pls-glm-family","pls-glm-Gamma","pls-glm-gaussian","pls-glm-inverse.gaussian","pls-glm-poisson")) {
 if (kk==1) {
 tempconstglm <- glm(YwotNA~1,family=family)
 res$Coeffsmodel_vals <- rbind(summary(tempconstglm)$coefficients,matrix(rep(NA,4*nt),ncol=4))
@@ -388,7 +403,7 @@ res$Yresidus <- dataY-res$YChapeau
 ##############################################
 ######              PLS-GLM             ######
 ##############################################
-if (modele %in% c("pls-glm-gaussian","pls-glm-logistic")) {
+if (modele %in% c("pls-glm-logistic","pls-glm-family","pls-glm-Gamma","pls-glm-gaussian","pls-glm-inverse.gaussian","pls-glm-poisson")) {
 res$residYChapeau <- tempregglm$linear.predictors
 
 
@@ -422,7 +437,7 @@ if (na.miss.X & !na.miss.Y) {
 
 
 if (kk==1) {
-cat("____Il y a des NA dans X et pas dans Y____\n")
+cat("____There are some NAs in X but not in Y____\n")
 }
 
 ##############################################
@@ -446,7 +461,7 @@ res$Yresidus <- dataY-res$YChapeau
 ##############################################
 ######              PLS-GLM             ######
 ##############################################
-if (modele %in% c("pls-glm-gaussian","pls-glm-logistic")) {
+if (modele %in% c("pls-glm-logistic","pls-glm-family","pls-glm-Gamma","pls-glm-gaussian","pls-glm-inverse.gaussian","pls-glm-poisson")) {
 res$residYChapeau <- tempregglm$linear.predictors
 
 
@@ -469,7 +484,7 @@ rownames(res$Coeffs) <- rownames(res$Std.Coeffs)
 
 else {
 if (kk==1) {
-cat("____Il y a des NA dans X et aussi dans Y____\n")
+cat("____There are some NAs both in X and Y____\n")
 }
 }
 }
@@ -503,7 +518,7 @@ rm(tempConstante)
 ##############################################
 ######              PLS-GLM             ######
 ##############################################
-if (modele %in% c("pls-glm-gaussian","pls-glm-logistic")) {
+if (modele %in% c("pls-glm-logistic","pls-glm-family","pls-glm-Gamma","pls-glm-gaussian","pls-glm-inverse.gaussian","pls-glm-poisson")) {
 res$residY <- res$residY 
 res$residusY <- cbind(res$residusY,res$residY)
 
@@ -557,7 +572,7 @@ for (ii in 1:nrow(PredictYwotNA)) {
 colnames(res$ttPredictY) <- paste("tt",1:kk,sep="")
 }
 else {
-cat("____Il y a des NA dans X et aussi dans Y____\n")
+cat("____There are some NAs both in X and Y____\n")
 }
 }
 
@@ -607,7 +622,7 @@ res$listValsPredictY <- cbind(res$listValsPredictY,attr(res$RepY,"scaled:center"
 ##############################################
 ######              PLS-GLM             ######
 ##############################################
-if (modele %in% c("pls-glm-gaussian","pls-glm-logistic")) {
+if (modele %in% c("pls-glm-logistic","pls-glm-family","pls-glm-Gamma","pls-glm-gaussian","pls-glm-inverse.gaussian","pls-glm-poisson")) {
 tt <- res$ttPredictY
 res$listValsPredictY <- cbind(res$listValsPredictY,predict(object=tempregglm,newdata=data.frame(tt),type = "response"))
 }
