@@ -31,6 +31,8 @@ else {
     attr(ExpliX,"scaled:scale") <- rep(1,ncol(dataX))
     PredictY <- (dataPredictY)
 }
+if(is.null(colnames(ExpliX))){colnames(ExpliX)<-paste("X",1:ncol(ExpliX),sep=".")}
+if(is.null(rownames(ExpliX))){rownames(ExpliX)<-1:nrow(ExpliX)}
 
 if (any(is.na(dataX))) {na.miss.X <- TRUE} else na.miss.X <- FALSE
 if (any(is.na(dataY))) {na.miss.Y <- TRUE} else na.miss.Y <- FALSE
@@ -519,7 +521,7 @@ if (na.miss.X & !na.miss.Y) {
 
 
 if (kk==1) {
-cat("____Il y a des NA dans X et pas dans Y____\n")
+cat("____There are some NAs in X but not in Y____\n")
 }
 
 ##############################################
@@ -581,7 +583,7 @@ rownames(res$Coeffs) <- rownames(res$Std.Coeffs)
 
 else {
 if (kk==1) {
-cat("____Il y a des NA dans X et aussi dans Y____\n")
+cat("____There are some NAs both in X and Y____\n")
 }
 }
 }
@@ -717,7 +719,7 @@ for (ii in 1:nrow(PredictYwotNA)) {
 colnames(res$ttPredictY) <- paste("tt",1:res$computed_nt,sep="")
 }
 else {
-cat("____Il y a des NA dans X et aussi dans Y____\n")
+cat("____There are some NAs both in X and Y____\n")
 }
 }
 
